# Wlr layout UI

An experimental GUI to setup the screens layout on wlroots based systems.

## Requires

- wlr-randr

## Usage

```
wlrlui
```

## Limitations

Only allows to change screen positions, not the mode yet.
